@@ -2,11 +2,12 @@
 #'
 #' @description
 #' `recur_for_count()` controls the total number of events in the recurrence
-#' set. Using `recur_for_count()` will override the `until` date of the rule.
+#' set.
 #'
 #' @details
 #' Remember that the number of times the occurrence has occurred is counted
-#' from the `since` date! Adjust it as necessary to get your desired results.
+#' from the `since` date and is limited by the `until` date! Adjust them as
+#' necessary to get your desired results.
 #'
 #' @param x `[rrule]`
 #'
@@ -35,24 +36,16 @@
 #' # example below, they are not added to the total count. Only true event
 #' # dates are counted.
 #' on_31_for_5 <- monthly(since = "2019-01-01") %>%
-#'   recur_on_mday(31) %>%
+#'   recur_on_day_of_month(31) %>%
 #'   recur_for_count(5)
 #'
 #' alma_search("2019-01-01", "2020-01-01", on_31_for_5)
 recur_for_count <- function(x, n) {
-  validate_rrule(x, "x")
+  check_rrule(x)
+  check_rule_not_set(x, "count")
 
-  if (is_already_set(x, "count")) {
-    abort("`count` has already been set for this rrule.")
-  }
+  check_number_whole(n, min = 1)
+  n <- vec_cast(n, to = integer())
 
-  n <- vec_cast(n, integer(), x_arg = "n")
-  vec_assert(n, size = 1L)
-
-  if (n <= 0L) {
-    abort("`n` must be greater than 0.")
-  }
-
-  # Override `until`
-  tweak_rrule(x, until = NULL, count = n)
+  tweak_rrule(x, count = n)
 }
