@@ -10,10 +10,18 @@ test_that("events stop after `count` is up", {
   expect_equal(x, expect)
 })
 
-test_that("`count` overrides `until`", {
+test_that("`count` is limited by `until`", {
   rrule <- daily(since = "1970-01-01", until = "1970-01-02") %>%
     recur_for_count(3)
 
+  expect_identical(
+    alma_search("1970-01-01", "1970-01-05", rrule),
+    new_date(c(0, 1))
+  )
+
+  rrule <- daily(since = "1970-01-01", until = "1970-01-03") %>%
+    recur_for_count(3)
+
   expect_identical(
     alma_search("1970-01-01", "1970-01-05", rrule),
     new_date(c(0, 1, 2))
@@ -21,10 +29,9 @@ test_that("`count` overrides `until`", {
 })
 
 test_that("`count` can only be set once", {
-  expect_error(
-    daily() %>% recur_for_count(2) %>% recur_for_count(2),
-    "`count` has already been set"
-  )
+  expect_snapshot(error = TRUE, {
+    daily() %>% recur_for_count(2) %>% recur_for_count(2)
+  })
 })
 
 test_that("impossible dates do not count towards the count", {
@@ -41,6 +48,8 @@ test_that("impossible dates do not count towards the count", {
 })
 
 test_that("`count` must be castable to a scalar integer", {
-  expect_error(daily() %>% recur_for_count("a"), class = "vctrs_error_incompatible_type")
-  expect_error(daily() %>% recur_for_count(c(1, 2)), class = "vctrs_error_assert_size")
+  expect_snapshot({
+    (expect_error(daily() %>% recur_for_count("a")))
+    (expect_error(daily() %>% recur_for_count(c(1, 2))))
+  })
 })
